@@ -39,7 +39,7 @@ class ChannelsNotPresent(Exception):
     channels = []
 
     def __init__(self, channels, recordid="Unknown"):
-        msg = "Channels of record %s where not present: %s" % (recordid, channels)
+        msg = "Channels of record %s where not present: %s, you can define 'aliases' for the channelname or make the channel optional" % (recordid, channels)
         super().__init__(msg)
         self.channels = channels
 
